@@ -22,6 +22,7 @@ from pypika import Order, Query, Table
 from tortoise.backends.base.client import BaseDBAsyncClient
 from tortoise.exceptions import (
     ConfigurationError,
+    DoesNotExist,
     IncompleteInstanceError,
     IntegrityError,
     OperationalError,
@@ -41,7 +42,7 @@ from tortoise.fields.relational import (
 )
 from tortoise.filters import get_filters_for_field
 from tortoise.functions import Function
-from tortoise.queryset import Q, QuerySet, QuerySetSingle
+from tortoise.queryset import ExistsQuery, Q, QuerySet, QuerySetSingle
 from tortoise.signals import Signals
 from tortoise.transactions import current_transaction_map, in_transaction
 
@@ -602,6 +603,9 @@ class ModelMeta(type):
         meta.finalise_fields()
         return new_class
 
+    def __getitem__(cls: Type[MODEL], key: Any) -> QuerySetSingle[MODEL]:  # type: ignore
+        return cls._getbypk(key)  # type: ignore
+
 
 class Model(metaclass=ModelMeta):
     """
@@ -728,6 +732,13 @@ class Model(metaclass=ModelMeta):
     Can be used as a field name when doing filtering e.g. ``.filter(pk=...)`` etc...
     """
 
+    @classmethod
+    async def _getbypk(cls: Type[MODEL], key: Any) -> MODEL:
+        try:
+            return await cls.get(pk=key)
+        except (DoesNotExist, ValueError):
+            raise KeyError(f"{cls._meta.full_name} has no object {repr(key)}")
+
     def update_from_dict(self, data: dict) -> MODEL:
         """
         Updates the current model with the provided dict.
@@ -1015,6 +1026,20 @@ class Model(metaclass=ModelMeta):
         """
         return QuerySet(cls).get(*args, **kwargs)
 
+    @classmethod
+    def exists(cls: Type[MODEL], *args: Q, **kwargs: Any) -> ExistsQuery:
+        """
+        Return True/False whether record exists with the provided filter parameters.
+
+        .. code-block:: python3
+
+            result = await User.exists(username="foo")
+
+        :param args: Q funtions containing constraints. Will be AND'ed.
+        :param kwargs: Simple filter constraints.
+        """
+        return QuerySet(cls).filter(*args, **kwargs).exists()
+
     @classmethod
     def get_or_none(cls: Type[MODEL], *args: Q, **kwargs: Any) -> QuerySetSingle[Optional[MODEL]]:
         """
